==> firefox-61.0b6.source.tar.xz: firefox-61.0/browser/extensions/activity-stream/prerendered/locales/hr/activity-stream-strings.js <==
// Note - this is a generated hr file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nova kartica",
  "header_top_sites": "Najbolje stranice",
  "header_highlights": "Istaknuto",
  "header_recommended_by": "Preporučeno od {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Posjećeno",
  "type_label_bookmarked": "Zabilježeno",
  "type_label_recommended": "Popularno",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Zabilježi stranicu",
  "menu_action_remove_bookmark": "Ukloni zabilješku",
  "menu_action_open_new_window": "Otvori u novom prozoru",
  "menu_action_open_private_window": "Otvori u novom privatnom prozoru",
  "menu_action_dismiss": "Odbaci",
  "menu_action_delete": "Obriši iz povijesti",
  "menu_action_pin": "Zakači",
  "menu_action_unpin": "Otkači",
  "confirm_history_delete_p1": "Jeste li sigurni da želite obrisati sve primjere ove stranice iz vaše povijesti?",
  "confirm_history_delete_notice_p2": "Ova radnja je nepovratna.",
  "menu_action_save_to_pocket": "Spremi u Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Traži",
  "search_header": "{search_engine_name} pretraživanje",
  "search_web_placeholder": "Pretraži web",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Prilagodite svoju početnu stranicu nove kartice",
  "settings_pane_topsites_header": "Najbolje stranice",
  "settings_pane_highlights_header": "Istaknuto",
  "settings_pane_highlights_options_bookmarks": "Zabilješke",
  "settings_pane_snippets_header": "Isječci",
  "edit_topsites_button_text": "Uredi",
  "edit_topsites_edit_button": "Uredi ovu stranicu",
  "topsites_form_add_header": "Nova najbolja stranica",
  "topsites_form_edit_header": "Uredi najbolju stranicu",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Unesi naslov",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Utipkajte ili zalijepite URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Dodaj",
  "topsites_form_save_button": "Spremi",
  "topsites_form_cancel_button": "Otkaži",
  "topsites_form_url_validation": "Potrebno je unijeti ispravan URL",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Popularne teme:",
  "pocket_read_even_more": "Prikaži više priča",
  "highlights_empty_state": "Započnite pretraživati i pokazat ćemo vam neke od izvrsnih članaka, videa i drugih web stranica prema vašim nedavno posjećenim stranicama ili zabilješkama.",
  "topstories_empty_state": "Provjerite kasnije za više najpopularnijih priča od {provider}. Ne možete čekati? Odaberite popularne teme kako biste pronašli više kvalitetnih priča s cijelog weba.",
  "manual_migration_explanation2": "Probajte Firefox s zabilješkama, povijesti i lozinkama iz drugog pretraživača.",
  "manual_migration_cancel_button": "Ne hvala",
  "manual_migration_import_button": "Uvezi sada",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "default_label_loading": "Učitavanje…",
  "header_stories": "Najbolje priče",
  "header_visit_again": "Posjetite ponovno",
  "header_bookmarks": "Nedavne zabilješke",
  "header_bookmarks_placeholder": "Još nemate niti jednu zabilješku.",
  "header_stories_from": "od",
  "type_label_synced": "Sinkronizirano s drugog uređaja",
  "type_label_open": "Otvori",
  "type_label_topic": "Tema",
  "type_label_now": "Sada",
  "menu_action_copy_address": "Kopiraj adresu",
  "menu_action_email_link": "Pošalji poveznicu e-poštom…",
  "search_for_something_with": "Traži {search_term} s:",
  "search_settings": "Promijeni postavke pretraživanja",
  "section_info_option": "Info",
  "section_info_send_feedback": "Pošaljite povratnu informaciju",
  "section_info_privacy_notice": "Politika privatnosti",
  "welcome_title": "Dobro došli u novu karticu",
  "welcome_body": "Firefox će koristiti ovaj prostor kako bi vam pokazao najbitnije zabilješke, članke, video uratke i stranice koje ste nedavno posjetili, tako da se možete lako vratiti na njih.",
  "welcome_label": "Identificiranje istaknutog",
  "time_label_less_than_minute": "<1m",
  "time_label_minute": "{number}m",
  "time_label_hour": "{number}h",
  "time_label_day": "{number}d",
  "settings_pane_header": "Postavke nove kartice",
  "settings_pane_body2": "Odaberite što vidite na ovoj stranici.",
  "settings_pane_search_header": "Traži",
  "settings_pane_search_body": "Pretražite Web iz nove kartice.",
  "settings_pane_topsites_body": "Pristupite stranicama koje najčešće posjećujete.",
  "settings_pane_topsites_options_showmore": "Prikaži dva reda",
  "settings_pane_bookmarks_header": "Nedavne zabilješke",
  "settings_pane_bookmarks_body": "Vaše novo stvorene zabilješke na jednom praktičnom mjestu.",
  "settings_pane_visit_again_header": "Posjetite ponovno",
  "settings_pane_visit_again_body": "Firefox će vam prikazati dijelove vaše povijesti pretraživanja koje možda želite zapamtiti ili posjetiti ponovno.",
  "settings_pane_highlights_body2": "Pronađite put natrag do zanimljivih stvari koje ste nedavno posjetili ili zabilježili.",
  "settings_pane_highlights_options_visited": "Posjećene stranice",
  "settings_pane_snippets_body": "Pročitajte kratke i slatke obavijesti od Mozille o Firefoxu, internet kulturi i povremenim nasumičnim temama.",
  "settings_pane_done_button": "Gotovo",
  "edit_topsites_button_label": "Prilagodite odjel s najboljim stranicama",
  "edit_topsites_showmore_button": "Prikaži više",
  "edit_topsites_showless_button": "Prikaži manje",
  "edit_topsites_done_button": "Gotovo",
  "edit_topsites_pin_button": "Zakači stranicu",
  "edit_topsites_unpin_button": "Otkači ovu stranicu",
  "edit_topsites_dismiss_button": "Odbaci stranicu",
  "edit_topsites_add_button": "Dodaj",
  "pocket_feedback_header": "Najbolje od interneta, birano od preko 25 miliona ljudi.",
  "pocket_description": "Otkrijte visoko kvalitetan sadržaj koji ste možda propustili, uz pomoć Pocketa koji je sada dio Mozille."
};

==> firefox-62.0b14.source.tar.xz: firefox-62.0/browser/extensions/activity-stream/prerendered/locales/hr/activity-stream-strings.js <==
// Note - this is a generated hr file.
window.gActivityStreamStrings = {
  "newtab_page_title": "Nova kartica",
  "header_top_sites": "Najbolje stranice",
  "header_highlights": "Istaknuto",
  "header_recommended_by": "Preporučeno od {provider}",
  "context_menu_button_sr": "Open context menu for {title}",
  "section_context_menu_button_sr": "Open the section context menu",
  "type_label_visited": "Posjećeno",
  "type_label_bookmarked": "Zabilježeno",
  "type_label_recommended": "Popularno",
  "type_label_pocket": "Saved to Pocket",
  "type_label_downloaded": "Downloaded",
  "menu_action_bookmark": "Zabilježi stranicu",
  "menu_action_remove_bookmark": "Ukloni zabilješku",
  "menu_action_open_new_window": "Otvori u novom prozoru",
  "menu_action_open_private_window": "Otvori u novom privatnom prozoru",
  "menu_action_dismiss": "Odbaci",
  "menu_action_delete": "Obriši iz povijesti",
  "menu_action_pin": "Zakači",
  "menu_action_unpin": "Otkači",
  "confirm_history_delete_p1": "Jeste li sigurni da želite obrisati sve primjere ove stranice iz vaše povijesti?",
  "confirm_history_delete_notice_p2": "Ova radnja je nepovratna.",
  "menu_action_save_to_pocket": "Spremi u Pocket",
  "menu_action_delete_pocket": "Delete from Pocket",
  "menu_action_archive_pocket": "Archive in Pocket",
  "menu_action_show_file_mac_os": "Show in Finder",
  "menu_action_show_file_windows": "Open Containing Folder",
  "menu_action_show_file_linux": "Open Containing Folder",
  "menu_action_show_file_default": "Show File",
  "menu_action_open_file": "Open File",
  "menu_action_copy_download_link": "Copy Download Link",
  "menu_action_go_to_download_page": "Go to Download Page",
  "menu_action_remove_download": "Remove from History",
  "search_button": "Traži",
  "search_header": "{search_engine_name} pretraživanje",
  "search_web_placeholder": "Pretraži web",
  "section_disclaimer_topstories": "The most interesting stories on the web, selected based on what you read. From Pocket, now part of Mozilla.",
  "section_disclaimer_topstories_linktext": "Learn how it works.",
  "section_disclaimer_topstories_buttontext": "Okay, got it",
  "prefs_home_header": "Firefox Home Content",
  "prefs_home_description": "Choose what content you want on your Firefox Home screen.",
  "prefs_section_rows_option": "{num} row;{num} rows",
  "prefs_search_header": "Web Search",
  "prefs_topsites_description": "The sites you visit most",
  "prefs_topstories_description2": "Great content from around the web, personalized for you",
  "prefs_topstories_options_sponsored_label": "Sponsored Stories",
  "prefs_topstories_sponsored_learn_more": "Learn more",
  "prefs_highlights_description": "A selection of sites that you’ve saved or visited",
  "prefs_highlights_options_visited_label": "Visited Pages",
  "prefs_highlights_options_download_label": "Most Recent Download",
  "prefs_highlights_options_pocket_label": "Pages Saved to Pocket",
  "prefs_snippets_description": "Updates from Mozilla and Firefox",
  "settings_pane_button_label": "Prilagodite svoju početnu stranicu nove kartice",
  "settings_pane_topsites_header": "Najbolje stranice",
  "settings_pane_highlights_header": "Istaknuto",
  "settings_pane_highlights_options_bookmarks": "Zabilješke",
  "settings_pane_snippets_header": "Isječci",
  "edit_topsites_button_text": "Uredi",
  "edit_topsites_edit_button": "Uredi ovu stranicu",
  "topsites_form_add_header": "Nova najbolja stranica",
  "topsites_form_edit_header": "Uredi najbolju stranicu",
  "topsites_form_title_label": "Title",
  "topsites_form_title_placeholder": "Unesi naslov",
  "topsites_form_url_label": "URL",
  "topsites_form_image_url_label": "Custom Image URL",
  "topsites_form_url_placeholder": "Utipkajte ili zalijepite URL",
  "topsites_form_use_image_link": "Use a custom image…",
  "topsites_form_preview_button": "Preview",
  "topsites_form_add_button": "Dodaj",
  "topsites_form_save_button": "Spremi",
  "topsites_form_cancel_button": "Otkaži",
  "topsites_form_url_validation": "Potrebno je unijeti ispravan URL",
  "topsites_form_image_validation": "Image failed to load. Try a different URL.",
  "pocket_read_more": "Popularne teme:",
  "pocket_read_even_more": "Prikaži više priča",
  "highlights_empty_state": "Započnite pretraživati i pokazat ćemo vam neke od izvrsnih članaka, videa i drugih web stranica prema vašim nedavno posjećenim stranicama ili zabilješkama.",
  "topstories_empty_state": "Provjerite kasnije za više najpopularnijih priča od {provider}. Ne možete čekati? Odaberite popularne teme kako biste pronašli više kvalitetnih priča s cijelog weba.",
  "manual_migration_explanation2": "Probajte Firefox s zabilješkama, povijesti i lozinkama iz drugog pretraživača.",
  "manual_migration_cancel_button": "Ne hvala",
  "manual_migration_import_button": "Uvezi sada",
  "error_fallback_default_info": "Oops, something went wrong loading this content.",
  "error_fallback_default_refresh_suggestion": "Refresh page to try again.",
  "section_menu_action_remove_section": "Remove Section",
  "section_menu_action_collapse_section": "Collapse Section",
  "section_menu_action_expand_section": "Expand Section",
  "section_menu_action_manage_section": "Manage Section",
  "section_menu_action_manage_webext": "Manage Extension",
  "section_menu_action_add_topsite": "Add Top Site",
  "section_menu_action_move_up": "Move Up",
  "section_menu_action_move_down": "Move Down",
  "section_menu_action_privacy_notice": "Privacy Notice",
  "firstrun_title": "Take Firefox with You",
  "firstrun_content": "Get your bookmarks, history, passwords and other settings on all your devices.",
  "firstrun_learn_more_link": "Learn more about Firefox Accounts",
  "firstrun_form_header": "Enter your email",
  "firstrun_form_sub_header": "to continue to Firefox Sync",
  "firstrun_email_input_placeholder": "Email",
  "firstrun_extra_legal_links": "By proceeding, you agree to the {terms} and {privacy}.",
  "firstrun_terms_of_service": "Terms of Service",
  "firstrun_privacy_notice": "Privacy Notice",
  "firstrun_continue_to_login": "Continue",
  "firstrun_skip_login": "Skip this step",
  "default_label_loading": "Učitavanje…",
  "header_stories": "Najbolje priče",
  "header_visit_again": "Posjetite ponovno",
  "header_bookmarks": "Nedavne zabilješke",
  "header_bookmarks_placeholder": "Još nemate niti jednu zabilješku.",
  "header_stories_from": "od",
  "type_label_synced": "Sinkronizirano s drugog uređaja",
  "type_label_open": "Otvori",
  "type_label_topic": "Tema",
  "type_label_now": "Sada",
  "menu_action_copy_address": "Kopiraj adresu",
  "menu_action_email_link": "Pošalji poveznicu e-poštom…",
  "search_for_something_with": "Traži {search_term} s:",
  "search_settings": "Promijeni postavke pretraživanja",
  "section_info_option": "Info",
  "section_info_send_feedback": "Pošaljite povratnu informaciju",
  "section_info_privacy_notice": "Politika privatnosti",
  "welcome_title": "Dobro došli u novu karticu",
  "welcome_body": "Firefox će koristiti ovaj prostor kako bi vam pokazao najbitnije zabilješke, članke, video uratke i stranice koje ste nedavno posjetili, tako da se možete lako vratiti na njih.",
  "welcome_label": "Identificiranje istaknutog",
  "time_label_less_than_minute": "<1m",
  "time_label_minute": "{number}m",
  "time_label_hour": "{number}h",
  "time_label_day": "{number}d",
  "settings_pane_header": "Postavke nove kartice",
  "settings_pane_body2": "Odaberite što vidite na ovoj stranici.",
  "settings_pane_search_header": "Traži",
  "settings_pane_search_body": "Pretražite Web iz nove kartice.",
  "settings_pane_topsites_body": "Pristupite stranicama koje najčešće posjećujete.",
  "settings_pane_topsites_options_showmore": "Prikaži dva reda",
  "settings_pane_bookmarks_header": "Nedavne zabilješke",
  "settings_pane_bookmarks_body": "Vaše novo stvorene zabilješke na jednom praktičnom mjestu.",
  "settings_pane_visit_again_header": "Posjetite ponovno",
  "settings_pane_visit_again_body": "Firefox će vam prikazati dijelove vaše povijesti pretraživanja koje možda želite zapamtiti ili posjetiti ponovno.",
  "settings_pane_highlights_body2": "Pronađite put natrag do zanimljivih stvari koje ste nedavno posjetili ili zabilježili.",
  "settings_pane_highlights_options_visited": "Posjećene stranice",
  "settings_pane_snippets_body": "Pročitajte kratke i slatke obavijesti od Mozille o Firefoxu, internet kulturi i povremenim nasumičnim temama.",
  "settings_pane_done_button": "Gotovo",
  "edit_topsites_button_label": "Prilagodite odjel s najboljim stranicama",
  "edit_topsites_showmore_button": "Prikaži više",
  "edit_topsites_showless_button": "Prikaži manje",
  "edit_topsites_done_button": "Gotovo",
  "edit_topsites_pin_button": "Zakači stranicu",
  "edit_topsites_unpin_button": "Otkači ovu stranicu",
  "edit_topsites_dismiss_button": "Odbaci stranicu",
  "edit_topsites_add_button": "Dodaj",
  "pocket_feedback_header": "Najbolje od interneta, birano od preko 25 miliona ljudi.",
  "pocket_description": "Otkrijte visoko kvalitetan sadržaj koji ste možda propustili, uz pomoć Pocketa koji je sada dio Mozille."
};
